<?php
function xf_get_permalink($postId) {
	$link = get_permalink($postId);
	$faked = 'abc';
	$home = home_url($faked);
	
	return str_replace(str_replace($faked, '', $home), '', $link);
}

function xf_change_url($url) {
	$xf = XenForo_WP::create();
	$url_parsed = parse_url($url);
	$home_parsed = parse_url(get_option('home'));
	$proxyBase = $xf->getProxyBase();
	if ($proxyBase === false) {
		// no proxy configured?
		// this shouldn't happen, maybe misconfigured
		$xf_url = $xf->options['boardUrl'];
	} else {
		$xf_url = $proxyBase;
	}
	$xf_parsed = parse_url($xf_url);
	
	$subPath = str_replace($home_parsed['path'], '', $url_parsed['path']);
	/* there are places we won't change */
	$parts = explode('/', $subPath);
	$firstPart = false;
	$lastPart = false;
	foreach ($parts as $part) {
		$part = trim($part);
		if (strlen($part) > 0) {
			if ($firstPart === false) $firstPart = $part;
			$lastPart = $part;
		}
	}
	unset($parts);
	if (in_array($firstPart, array(
		'wp-admin', /* we don't give a sh*t about the Dashboard */
		'wp-content', /* and content also, routing all those images would be a nightmare (possible?) */
	))) {
		return $url;
	}
	if (in_array($lastPart, array(
		'feed', /* let the feeds alone */
	))) {
		return $url;
	}
	
	/* parse */
	$parsed = $url_parsed;
	$parsed['host'] = $xf_parsed['host']; // exchange the host
	if (XenForo_WP::create()->options['useFriendlyUrls']) {
		$parsed['path'] = $xf_parsed['path'] . $subPath;
	} else {
		$parsed['path'] = $xf_parsed['path'];
		$parsed_query = $xf_parsed['query'] . $subPath;
		if (!empty($parsed_query) AND !empty($parsed['query'])) {
			$parsed['query'] = $parsed_query . '&' . $parsed['query'];
		} else {
			$parsed['query'] = $parsed_query;
		}
		unset($xf_parsed['query']);
	}
	if (defined('WP_REQUEST_PARSED')) {
		$parsed['path'] = str_replace('//', '/', $parsed['path']);
		if (!empty($parsed['query'])) $parsed['query'] = str_replace('//', '/', $parsed['query']);		
	}
	
	/* merge */
	$result = "$parsed[scheme]://$parsed[host]$parsed[path]";
	if (!empty($xf_parsed['query'])) $result .= "?$xf_parsed[query]"; // append query (of XenForo)
	if (!empty($parsed['query'])) {
		// append query (of the URL)
		if (strpos($result, '?') === false) {
			// no query yet
			$result .= "?$parsed[query]";
		} else {
			// query string is not empty, append it
			$result .= "&$parsed[query]";
		}
	}
	/* polishing */
	
	$result = str_replace('/?', '?', $result);
	
	/* done */
	return $result;
}

function xf_home_url($url) {
	if (class_exists('XenForo_Application') OR defined('WP_REQUEST_PARSED')) {
		// we only modify the url if we are inside Proxy
		// OR the parsing procedure is completed (don't mess up with it, REALLY)
		if (class_exists('XenForo_Application') OR get_option('xf_always_run_in_proxy')) {
			// we only modify the url if we are inside Proxy
			// OR the always proxy mode is enabled
			return xf_change_url($url);
		} else {
			return $url;
		}
	} else {
		return $url;
	}
}
add_filter('home_url', 'xf_home_url');

function xf_site_url($url, $path = '') {
	if (get_option('xf_always_run_in_proxy') AND $path != 'wp-admin/') {
		return xf_change_url($url);
	} else {
		// nothing to do with site url
		// even if we are in the proxy, the site url should always stay the same
		return $url;
	}
}
add_filter('site_url', 'xf_site_url', 10, 2);

function xf_default_stuff(WP_Dependencies $stuff) {
	// full URL with trailing slash - YES SIR!
	$stuff->base_url = get_option('home');
}
add_action('wp_default_styles', 'xf_default_stuff');
add_action('wp_default_scripts', 'xf_default_stuff');

function xf_redirect_canonical($requested_url = null, $do_redirect = true) {
	$redirect_url = redirect_canonical($requested_url, $do_redirect);
	if (get_option('xf_always_run_in_proxy')) {
		// we will check to make sure we are in proxy
		if (!class_exists('XenForo_Application') AND $redirect_url === false) {
			// not in proxy, start redirecting
			if (!$requested_url) {
				// build the URL in the address bar
				$requested_url  = is_ssl() ? 'https://' : 'http://';
				$requested_url .= $_SERVER['HTTP_HOST'];
				$requested_url .= $_SERVER['REQUEST_URI'];
			}
			
			if (strpos($requested_url, get_option('home')) !== 0) return false; // we don't redirect non-home based url
			$redirect_url = xf_change_url($requested_url); // find the redirected url
			if (!$redirect_url OR $redirect_url == $requested_url) return false; // they are the same, huh?

			if ($do_redirect) {
				// protect against chained redirects
				if (!xf_redirect_canonical($redirect_url, false)) {
					wp_redirect($redirect_url, 301);
					exit();
				} else {
					return false;
				}
			} else {
				return $redirect_url;
			}
		}
	}
}
add_action('template_redirect', 'xf_redirect_canonical', 1, 2);
remove_action('template_redirect', 'redirect_canonical');

function xf_parse_request() {
	// request is parsed, mark it now
	define('WP_REQUEST_PARSED', true);
}
add_action('parse_request', 'xf_parse_request', 10, 0);