<?php
class XenForo_Wdiget_Abstract extends WP_Widget {
	function printCache($args, $instance) {
		$cache = wp_cache_get($this->id_base, 'widget');
		if (!is_array($cache)) $cache = array();
		if (isset($cache[$args['widget_id']]) AND $cache[$args['widget_id']]['time'] > time() - $instance['cache']*3600) {
			echo $cache[$args['widget_id']]['html'];
			return true;
		} else {
			return false;
		}
	}
	
	function saveCache($args, $instance, $html) {
		$cache = wp_cache_get($this->id_base, 'widget');
		if (!is_array($cache)) $cache = array();
		$cache[$args['widget_id']] = array('html' => $html, 'time' => time());
		wp_cache_set($this->id_base, $cache, 'widget');
	}
	
	function formCache($instance) {
		if (!isset($instance['cache']))	$cache = 1; else $cache = (int) $instance['cache'];
?>
		<p><label for="<?php echo $this->get_field_id('cache'); ?>"><?php _e('Cache (Hour):'); ?></label>
		<input id="<?php echo $this->get_field_id('cache'); ?>" name="<?php echo $this->get_field_name('cache'); ?>" type="text" value="<?php echo $cache; ?>" size="3" /></p>
<?php
	}
	
	function updateCache(&$instance, $new_instance, $old_instance) {
		$instance['cache'] = (int) $new_instance['cache'];
		wp_cache_delete($this->id_base, 'widget');
	}
}

class XenForo_Widget_Recent_Threads extends XenForo_Wdiget_Abstract {

	function XenForo_Widget_Recent_Threads() {
		$widget_ops = array('classname' => 'xf_widget_recent_threads', 'description' => __( "The most recent XenForo threads") );
		$this->WP_Widget('xf-recent-threads', __('[XenForo] Recent Threads'), $widget_ops);
		$this->alt_option_name = 'xf_widget_recent_threads';
	}

	function widget($args, $instance) {
		$xf = XenForo_WP::create();
		if ($xf->getUserId() == 0 AND $this->printCache($args, $instance)) {
			// only check cache if current user is not logged in
			return;
		}
		
		ob_start();
		extract($args);

		$doUnread = true;
		$userId = $xf->getUserId();
		
		$tabs = array();
		
		foreach (array('created', 'replied', 'viewed') as $type) {
			if (!$number = (int) $instance[$type . '_thread_number']) {
				$number = 10;
			} else if ($number < 1) { 
				$number = 1;
			} else if ($number > 15) {
				$number = 15;
			}
			if (!isset($instance[$type . '_thread_exclude']) || !is_array($exclude = $instance[$type . '_thread_exclude']))
				$exclude = array();
				
			$extraConditions = '';
			switch ($type) {
				case 'created':
					$tabName = __('New');
					$xf_user_join_condition = 'user.user_id = thread.user_id';
					$order_by = 'thread.post_date DESC';
					break;
				case 'replied':
					$tabName = __('Replied');
					$xf_user_join_condition = 'user.user_id = thread.last_post_user_id';
					$order_by = 'thread.last_post_date DESC';
					break;
				case 'viewed':
					$tabName = __('Popular');
					$xf_user_join_condition = 'user.user_id = thread.user_id';
					$order_by = 'thread.view_count DESC';
					if (!empty($instance['viewed_thread_datecut'])) {
						$extraConditions .= ' AND thread.last_post_date > ' . (time() - ((int)$instance['viewed_thread_datecut'])*86400);
					}
					break;
			}
			
			$threads = $xf->xfdb->get_results("
				SELECT 
					thread.thread_id,
					thread.title,
					thread.user_id AS thread_user_id,
					thread.username AS thread_username,
					thread.view_count,
					thread.reply_count,
					thread.first_post_likes,
					thread.post_date,
					thread.last_post_date
					
					" . (!empty($xf_user_join_condition)?("
					,user.user_id
					,user.username
					,user.gender
					,user.avatar_date, user.avatar_width, user.avatar_height
					,user.gravatar
					"):'') . "
					
					" . ($doUnread?($userId > 0?", IF(thread_read.thread_read_date IS NULL 
						AND forum_read.forum_read_date IS NULL, 1, 0) AS isUnread":", 0 AS isUnread"):'') . "
				FROM `xf_thread` AS thread
				" . (!empty($xf_user_join_condition)?("LEFT JOIN xf_user AS user ON $xf_user_join_condition"):'') . "
				" . (($doUnread AND $userId > 0)?"LEFT JOIN xf_thread_read AS thread_read ON
						(thread_read.thread_id = thread.thread_id AND thread_read.user_id = $userId
						AND thread_read.thread_read_date >= thread.last_post_date)
					LEFT JOIN xf_forum_read AS forum_read ON
						(forum_read.node_id = thread.node_id AND forum_read.user_id = $userId
						AND forum_read.forum_read_date >= thread.last_post_date)":'') . "
				WHERE thread.discussion_state = 'visible'
					" . (empty($exclude)?'':("AND thread.node_id NOT IN (" . implode(',',$exclude) . ")")) . "
					$extraConditions
				ORDER BY thread.last_post_date DESC
				LIMIT $number
			");
			
			if (count($threads) > 0):
				ob_start();
			
?>
				<ul>
					<?php  foreach ($threads as $thread): ?>
					<?php
						$titleClass = '';
						$threadLink = '';
						if ($thread->isUnread) {
							$titleClass .= ' xf-widget-unread';
							$threadLink = $this->buildLink($thread, 'unread');
						}
						if (empty($threadLink)) $threadLink = $this->buildLink($thread);
					?>
					<li class="xf-widget-item">
						<?php if (isset($thread->user_id) AND class_exists('bdWordPressProxy_TemplateHelper')): ?>
						<div class="xf-widget-cell xf-widget-avatar">
						<?php $user = (array) ($thread); ?>
						<?php echo bdWordPressProxy_TemplateHelper::prepare('XenForo_Template_Helper_Core::avatarHtml',array(
							$user,
							false,
							array(
								'user' => $user,
								'size' => 's',
								'itemprop' => 'photo'
							)
							,''
						)) ?>
						</div>
						<?php endif; ?>
						<div class="xf-widget-cell xf-widget-info">
							<?php if (class_exists('bdWordPressProxy_TemplateHelper')): ?>
							<a href="<?php echo $threadLink; ?>" class="PreviewTooltip xf-widget-thread-title<?php echo $titleClass; ?>" data-previewurl="<?php echo $this->buildLink($thread, 'preview'); ?>"><?php echo $thread->title; ?></a>
							<?php else: ?>
							<a href="<?php echo $threadLink; ?>" class="xf-widget-thread-title<?php echo $titleClass; ?>" title="<?php echo esc_attr($thread->title); ?>"><?php echo $thread->title; ?></a>
							<?php endif; ?>
							<div class="muted">
							<?php if ('created' == $type): ?>
							<div><?php printf(__('%s posted'), $thread->username); ?></div>
							<div><?php echo class_exists('bdWordPressProxy_TemplateHelper')
									?(XenForo_Template_Helper_Core::dateTimeHtml($thread->post_date))
									:mysql2date(get_option('date_format'), $thread->post_date); ?></div>
							<div><?php printf(_n('%d reply', '%d replies', $thread->reply_count), $thread->reply_count); ?></div>
							<?php elseif ('replied' == $type): ?>
							<div><?php printf(__('%s replied'), $thread->username); ?></div>
							<div><?php echo class_exists('bdWordPressProxy_TemplateHelper')
									?(XenForo_Template_Helper_Core::dateTimeHtml($thread->last_post_date))
									:mysql2date(get_option('date_format'), $thread->last_post_date); ?></div>
							<div><?php printf(_n('%d reply', '%d replies', $thread->reply_count), $thread->reply_count); ?></div>
							<?php else: ?>
							<div><?php printf(__('%s posted'), $thread->username); ?></div>
							<div><?php echo class_exists('bdWordPressProxy_TemplateHelper')
									?(XenForo_Template_Helper_Core::dateTimeHtml($thread->post_date))
									:mysql2date(get_option('date_format'), $thread->post_date); ?></div>
							<div><?php printf(_n('%d view', '%d views', $thread->view_count), $thread->view_count); ?></div>
							<?php endif; ?>
							</div>
						</div>
					</li>
					<?php endforeach; ?>
				</ul>
<?php
				$tabs[$tabName] = ob_get_clean();
			endif;
		}

		if (count($tabs) > 1):
			$widgetId = 'xf-widget-' . $args['widget_id'];
?>
			<?php echo $before_widget; ?>
			<div id="<?php echo $widgetId; ?>">
				<ul class="widget-title">
					<?php foreach (array_keys($tabs) as $i => $tabName): ?>
					<li><a href="#<?php echo $widgetId; ?>-<?php echo ($i + 1); ?>"><?php echo $tabName ?></a></li>
					<?php endforeach; ?>
				</ul>
				<?php foreach (array_values($tabs) as $i => $tab): ?>
				<div id="<?php echo $widgetId; ?>-<?php echo ($i + 1); ?>">
					<?php echo $tab; ?>
				</div><!-- #<?php echo $widgetId; ?>-<?php echo ($i + 1); ?> -->
				<?php endforeach; ?>
			</div><!-- #<?php echo $widgetId; ?> -->
			<?php echo $after_widget; ?>
			<script type="text/javascript">
				jQuery(function() {
					jQuery("#<?php echo $widgetId; ?>").tabs();
				});
			</script>
			<?php if (class_exists('bdWordPressProxy_TemplateHelper')): ?>
			<div id="PreviewTooltip"> 
				<span class="arrow"><span></span></span> 
				
				<div class="section"> 
					<div class="primaryContent previewContent"> 
						<span class="PreviewContents">Loading...</span> 
					</div> 
				</div> 
			</div>
			<?php endif; ?> 
<?php
		endif;

		$this->saveCache($args, $instance, ob_get_flush());
	}
	
	function buildLink($thread, $action = '') {
		return XenForo_WP::create()->buildPublicLink($action?('threads/' . $action):'threads', array(
			'thread_id' => $thread->thread_id,
			'title' => $thread->title,
		));
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['created_thread_number'] = (int) $new_instance['created_thread_number'];
		$instance['created_thread_exclude'] = (array) $new_instance['created_thread_exclude'];
		$instance['replied_thread_number'] = (int) $new_instance['replied_thread_number'];
		$instance['replied_thread_exclude'] = (array) $new_instance['replied_thread_exclude'];
		$instance['viewed_thread_number'] = (int) $new_instance['viewed_thread_number'];
		$instance['viewed_thread_exclude'] = (array) $new_instance['viewed_thread_exclude'];
		$instance['viewed_thread_datecut'] = (array) $new_instance['viewed_thread_datecut'];
		
		$this->updateCache($instance, $new_instance, $old_instance);

		return $instance;
	}
	
	function form($instance) {
		if (!isset($instance['created_thread_number']) || !$created_thread_number = (int) $instance['created_thread_number'])
			$created_thread_number = 5;
		if (!isset($instance['created_thread_exclude']) || !is_array($created_thread_exclude = $instance['created_thread_exclude']))
			$created_thread_exclude = array();
		if (!isset($instance['replied_thread_number']) || !$replied_thread_number = (int) $instance['replied_thread_number'])
			$replied_thread_number = 5;
		if (!isset($instance['replied_thread_exclude']) || !is_array($replied_thread_exclude = $instance['replied_thread_exclude']))
			$replied_thread_exclude = array();
		if (!isset($instance['viewed_thread_number']) || !$viewed_thread_number = (int) $instance['viewed_thread_number'])
			$viewed_thread_number = 5;
		if (!isset($instance['viewed_thread_exclude']) || !is_array($viewed_thread_exclude = $instance['viewed_thread_exclude']))
			$viewed_thread_exclude = array();
		if (!isset($instance['viewed_thread_datecut']) || !$viewed_thread_datecut = (int) $instance['viewed_thread_datecut'])
			$viewed_thread_datecut = 7;
		if (!isset($instance['cache']) || !$cache = (int) $instance['cache'])
			$cache = 1;
			
		$forums = XenForo_WP::create()->getForums();
?>
		<p><label for="<?php echo $this->get_field_id('created_thread_number'); ?>"><?php _e('Created threads:'); ?></label>
		<input id="<?php echo $this->get_field_id('created_thread_number'); ?>" name="<?php echo $this->get_field_name('created_thread_number'); ?>" type="text" value="<?php echo $created_thread_number; ?>" size="3" /></p>
		<p>
			<label for="<?php echo $this->get_field_id('created_thread_exclude'); ?>"><?php _e('Created threads exclude forums:'); ?></label><br/>
			<select class="widefat" id="<?php echo $this->get_field_id('created_thread_exclude'); ?>" name="<?php echo $this->get_field_name('created_thread_exclude'); ?>[]" size="5" multiple="multiple" style="height: auto">
				<?php foreach ($forums as $forum): ?>
				<option value="<?php echo $forum->node_id; ?>"<?php if (in_array($forum->node_id, $created_thread_exclude)): ?> selected="selected"<?php endif; ?>><?php echo str_repeat('--', $forum->depth) . $forum->title; ?></option>
				<?php endforeach; ?>
			</select>
		</p>
		
		<p><label for="<?php echo $this->get_field_id('replied_thread_number'); ?>"><?php _e('Replied threads:'); ?></label>
		<input id="<?php echo $this->get_field_id('replied_thread_number'); ?>" name="<?php echo $this->get_field_name('replied_thread_number'); ?>" type="text" value="<?php echo $replied_thread_number; ?>" size="3" /></p>
		<p>
			<label for="<?php echo $this->get_field_id('replied_thread_exclude'); ?>"><?php _e('Replied threads exclude forums:'); ?></label><br/>
			<select class="widefat" id="<?php echo $this->get_field_id('replied_thread_exclude'); ?>" name="<?php echo $this->get_field_name('replied_thread_exclude'); ?>[]" size="5" multiple="multiple" style="height: auto">
				<?php foreach ($forums as $forum): ?>
				<option value="<?php echo $forum->node_id; ?>"<?php if (in_array($forum->node_id, $replied_thread_exclude)): ?> selected="selected"<?php endif; ?>><?php echo str_repeat('--', $forum->depth) . $forum->title; ?></option>
				<?php endforeach; ?>
			</select>
		</p>
		
		<p><label for="<?php echo $this->get_field_id('viewed_thread_number'); ?>"><?php _e('Viewed threads:'); ?></label>
		<input id="<?php echo $this->get_field_id('viewed_thread_number'); ?>" name="<?php echo $this->get_field_name('viewed_thread_number'); ?>" type="text" value="<?php echo $viewed_thread_number; ?>" size="3" /></p>
		<p>
			<label for="<?php echo $this->get_field_id('viewed_thread_exclude'); ?>"><?php _e('Viewed threads exclude forums:'); ?></label><br/>
			<select class="widefat" id="<?php echo $this->get_field_id('viewed_thread_exclude'); ?>" name="<?php echo $this->get_field_name('viewed_thread_exclude'); ?>[]" size="5" multiple="multiple" style="height: auto">
				<?php foreach ($forums as $forum): ?>
				<option value="<?php echo $forum->node_id; ?>"<?php if (in_array($forum->node_id, $viewed_thread_exclude)): ?> selected="selected"<?php endif; ?>><?php echo str_repeat('--', $forum->depth) . $forum->title; ?></option>
				<?php endforeach; ?>
			</select>
		</p>
		<p><label for="<?php echo $this->get_field_id('viewed_thread_datecut'); ?>"><?php _e('Datecut (Day):'); ?></label>
		<input id="<?php echo $this->get_field_id('viewed_thread_datecut'); ?>" name="<?php echo $this->get_field_name('viewed_thread_datecut'); ?>" type="text" value="<?php echo $viewed_thread_datecut; ?>" size="3" /></p>
<?php
		
		$this->formCache($instance);
	}
}

class XenForo_Widget_Users extends XenForo_Wdiget_Abstract {

	function XenForo_Widget_Users() {
		$widget_ops = array('classname' => 'xf_widget_users', 'description' => __( "Newly registered users") );
		$this->WP_Widget('xf-users', __('[XenForo] Users'), $widget_ops);
		$this->alt_option_name = 'xf_widget_users';
	}

	function widget($args, $instance) {
		if ($this->printCache($args, $instance)) {
			return;
		}
		
		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('New Members') : $instance['title'], $instance, $this->id_base);
		if ( !$number = (int) $instance['number'] )
			$number = 10;
		else if ( $number < 1 )
			$number = 1;
		else if ( $number > 15 )
			$number = 15;

		$xf = XenForo_WP::create();
		$users = $xf->xfdb->get_results("
			SELECT user.*
			FROM `xf_user` AS user
			ORDER BY user.register_date DESC
			LIMIT $number
		");
		if (count($users) > 0):
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>
		<ul>
		<?php foreach ($users as $user): ?>
		<li class="xf-widget-item">
			<?php if (isset($user->user_id) AND class_exists('bdWordPressProxy_TemplateHelper')): ?>
			<div class="xf-widget-cell xf-widget-avatar">
			<?php $userArray = (array) ($user); ?>
			<?php echo bdWordPressProxy_TemplateHelper::prepare('XenForo_Template_Helper_Core::avatarHtml',array(
				$userArray,
				false,
				array(
					'user' => $userArray,
					'size' => 's',
					'itemprop' => 'photo'
				)
				,''
			)) ?>
			</div>
			<?php endif; ?>
			<div class="xf-widget-cell xf-widget-info">
				<a href="<?php echo $this->buildLink($user); ?>"><?php echo $user->username ?></a>
				<div class="muted">
				<div><?php echo class_exists('bdWordPressProxy_TemplateHelper')
						?(XenForo_Template_Helper_Core::dateTimeHtml($user->register_date))
						:mysql2date(get_option('date_format'), $user->register_date); ?></div>
				<div><?php printf(_n('%d message', '%d messages', $user->message_count), $user->message_count); ?></div>		
			</div>
		</li>
		<?php endforeach; ?>
		</ul>
		<?php echo $after_widget; ?>
<?php
		endif;

		$this->saveCache($args, $instance, ob_get_flush());
	}
	
	function buildLink($user) {
		return XenForo_WP::create()->buildPublicLink('members', (array) ($user));
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		
		$this->updateCache($instance, $new_instance, $old_instance);

		return $instance;
	}
	
	function form($instance) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if (!isset($instance['number']) || !$number = (int) $instance['number'])
			$number = 3;

?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
		
		<p><label for="<?php echo $this->get_field_id('number'); ?>"><?php _e('Number of users to show:'); ?></label>
		<input id="<?php echo $this->get_field_id('number'); ?>" name="<?php echo $this->get_field_name('number'); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>
<?php
		$this->formCache($instance);
	}
}

class XenForo_Widget_Poll extends XenForo_Wdiget_Abstract {

	function XenForo_Widget_Poll() {
		$widget_ops = array('classname' => 'xf_widget_poll', 'description' => __( "Latest Poll") );
		$this->WP_Widget('xf-poll', __('[XenForo] Poll'), $widget_ops);
		$this->alt_option_name = 'xf_widget_poll';
	}

	function widget($args, $instance) {
		$xf = XenForo_WP::create();
		
		ob_start();
		extract($args);

		$title = apply_filters('widget_title', empty($instance['title']) ? __('Poll') : $instance['title'], $instance, $this->id_base);
		$poll = $xf->xfdb->get_row("
			SELECT poll.*
			FROM `xf_poll` AS poll
			INNER JOIN `xf_thread` AS thread ON (thread.thread_id = poll.content_id)
			WHERE poll.content_type = 'thread'
			" . (!empty($instance['thread_id'])?("AND poll.content_id = " . intval($instance['thread_id'])):'') . "
			ORDER BY thread.post_date DESC
			LIMIT 1
		");
		
		if (!empty($poll)) {
			$poll->responses = unserialize($poll->responses);
			if (is_array($poll->responses)) {
				foreach ($poll->responses as &$aResponse) {
					if (is_array($aResponse['voters'])) {
						foreach ($aResponse['voters'] as $voter) {
							if ($xf->getUserId() == $voter['user_id']) {
								$poll->isVoted = true;
								$aResponse['hasVoted'] = true;
							}
						}
					}
				}				
			}
			$poll->canVote = (class_exists('XenForo_Visitor') AND empty($poll->isVoted) AND $xf->getUserId() > 0 AND ($poll->close_date == 0 OR $poll->close_date > time()));
		}
		
		if (!empty($poll) AND !empty($poll->responses)):
?>
		<?php echo $before_widget; ?>
		<?php if ( $title ) echo $before_title . $title . $after_title; ?>
		<div id="xf-widget-poll-response-container">
		<div class="xf-widget-poll-question"><a href="<?php echo $this->buildLink($poll); ?>"><?php echo $poll->question; ?></a></div>
		<?php if ($poll->canVote): ?>
		<?php bdWordPressProxy_TemplateHelper::addJs('js/xenforo/discussion.js'); ?>
		<form action="<?php echo $this->buildLink($poll, 'poll-vote'); ?>"
			method="post"
			class="AutoValidator PollVoteForm"
			data-container="#xf-widget-poll-response-container">
		<?php endif; ?>
		<ol>
		<?php foreach ($poll->responses as $responseKey => $response): ?>
		<li class="xf-widget-poll-response<?php if (!empty($response['hasVoted'])): ?> voted<?php endif; ?>">
			<label for="response-<?php echo $responseKey?>">
				<?php if ($poll->canVote): ?>
				<?php if ($poll->multiple): ?>
				<input id="response-<?php echo $responseKey?>" type="checkbox" value="<?php echo $responseKey ?>" name="response_multiple[]" />
				<?php else: ?>
				<input id="response-<?php echo $responseKey?>" type="radio" value="<?php echo $responseKey ?>" name="response" />
				<?php endif; ?>
				<?php endif; ?>
				<?php echo $response['response']; ?>: <?php echo $poll->voter_count == 0?0:round($response['response_vote_count'] / $poll->voter_count * 100, 1); ?>%
			</label>
		</li>
		<?php endforeach; ?>
		</ol>
		<?php if ($poll->canVote): ?>
		<input type="submit" value="<?php echo __('Vote'); ?>" />
		<input type="hidden" name="_xfToken" value="<?php echo XenForo_Visitor::getInstance()->get('csrf_token_page'); ?>" />
		<input type="hidden" name="_from_wordpress" value="1" />
		</form>
		<?php endif; ?>
		</div>
		<?php echo $after_widget; ?>
<?php
		endif;

		ob_get_flush();
	}
	
	function buildLink($poll, $action = '') {
		if (empty($action)) {
			return XenForo_WP::create()->buildPublicLink('threads', array('thread_id' => $poll->content_id));
		} else {
			return XenForo_WP::create()->buildPublicLink('threads/' . $action, array('thread_id' => $poll->content_id));
		}
	}

	function update($new_instance, $old_instance) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['thread_id'] = (int) $new_instance['thread_id'];
		
		return $instance;
	}
	
	function form($instance) {
		$title = isset($instance['title']) ? esc_attr($instance['title']) : '';
		if (!isset($instance['thread_id']) || !$thread_id = (int) $instance['thread_id'])
			$thread_id = 0;

?>
		<p><label for="<?php echo $this->get_field_id('title'); ?>"><?php _e('Title:'); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php echo $title; ?>" /></p>
		<p><label for="<?php echo $this->get_field_id('thread_id'); ?>"><?php _e('Thread ID (zero for latest):'); ?></label>
		<input id="<?php echo $this->get_field_id('thread_id'); ?>" name="<?php echo $this->get_field_name('thread_id'); ?>" type="text" value="<?php echo $thread_id; ?>" size="3" /></p>

<?php
	}
}

function xf_widgets_init() {
	if ( !is_blog_installed() )
		return;

	register_widget('XenForo_Widget_Recent_Threads');
	register_widget('XenForo_Widget_Users');
	register_widget('XenForo_Widget_Poll');
}
add_action('widgets_init', 'xf_widgets_init');

function xf_widgets_load_stuff() {
	$path = rtrim(get_option('home'), '/') . '/wp-content/plugins/xenforo/';
	
	wp_register_style('jquery-ui-core', $path . 'css/ui.core.css');
	wp_register_style('jquery-ui-tabs', $path . 'css/ui.tabs.css');
	wp_register_style('xf-widget', $path . 'css/xf-widget.css');
	wp_print_styles('jquery-ui-core');
	wp_print_styles('jquery-ui-tabs');
	wp_print_styles('xf-widget');
	
	wp_print_scripts('jquery-ui-core');
	wp_print_scripts('jquery-ui-tabs');
}
add_action('wp_head', 'xf_widgets_load_stuff');
